"""Exceptions

This is an extension of :mod:`exceptions`.

"""

__version__ = "0.1.0"
__copyright__ = "Copyright (C) 2014 Ivan D Vasin"
__credits__ = ["Ivan D Vasin"]
__maintainer__ = "Ivan D Vasin"
__email__ = "nisavid@gmail.com"
__docformat__ = "restructuredtext"

from ._exc import *
